import React from "react";
import { Link } from "@components/Link";
import { ChevronRight, UserMultiple } from "@carbon/icons-react";

export interface RoomListProps {
  title?: string;
  children: React.ReactNode;
  className?: string;
}

export const RoomList: React.FC<RoomListProps> = ({
  title,
  children,
  className = "",
}) => {
  return (
    <div className={className}>
      {title && (
        <h4 className="font-karla text-3xl leading-9 font-bold text-grey-900 tracking-tighter">
          {title}
        </h4>
      )}
      <div className="flex flex-col gap-2 mt-5">{children}</div>
    </div>
  );
};

export interface RoomSpaceProps {
  title?: string;
  target: string;
  name: string;
  description: string;
  image: {
    src: string;
    alt: string;
  };
  members: number;
  tag: string;
  children: React.ReactNode;
  className?: string;
}

export const RoomSpace: React.FC<RoomSpaceProps> = ({
  title,
  target,
  name,
  description,
  image,
  members,
  tag,
  children,
  className = "",
}) => {
  return (
    <div className={className}>
      {title && (
        <h4 className="font-karla text-3xl leading-9 font-bold text-grey-900 tracking-tighter">
          {title}
        </h4>
      )}
      <div className="rounded-lg bg-grey-200 p-2 mt-5">
        <div>
          <Space
            target={target}
            name={name}
            tag={tag}
            description={description}
            image={image}
            members={members}
          />
        </div>
        <div className="flex flex-col gap-2 bg-white">{children}</div>
      </div>
    </div>
  );
};

export interface RoomProps {
  target: string;
  name: string;
  description: string;
  image: {
    src: string;
    alt: string;
  };
  members: number;
  tag: string;
}

export const Room: React.FC<RoomProps> = ({
  target,
  name,
  description,
  image,
  members,
  tag,
}) => {
  return (
    <Link
      className="block bg-white hover:bg-grey-900 border border-transparent focus:border-grey-900 transition-colors ease-in duration-50"
      to={target}
    >
      <div className="group relative flex items-center gap-3 py-4 px-5 sm:px-6">
        <div className="w-12 h-12 rounded-full overflow-hidden">
          <img
            className="w-full h-full object-cover"
            alt={image.alt}
            src={image.src}
          />
        </div>
        <div className="w-[calc(100%-3rem)] flex gap-4 sm:pr-8 md:pr-6 lg:pr-10">
          <div className="w-full sm:w-1/4 md:w-[30%] lg:w-1/4">
            <div className="font-plex flex flex-col justify-between">
              <span className="text-sm leading-5 font-medium text-grey-900 line-clamp-1 group-hover:text-white transition-colors ease-in duration-50">
                {name}
              </span>
              <span className="text-xs leading-4 font-normal text-grey-500 break-all line-clamp-1">
                {tag}
              </span>
              <span className="flex items-center text-xs leading-4 font-normal text-grey-500">
                <UserMultiple className="mr-2" /> {members}
              </span>
            </div>
          </div>
          <div className="hidden sm:block w-[75%]">
            <p className="font-plex text-sm leading-5 font-normal text-black line-clamp-3 group-hover:text-white transition-colors ease-in duration-50">
              {description}
            </p>
          </div>
        </div>
        <ChevronRight
          size={24}
          className="absolute top-1/2 right-4 lg:right-6 -translate-y-2/4 text-grey-500"
        />
      </div>
    </Link>
  );
};

export const Space: React.FC<RoomProps> = ({
  target,
  name,
  description,
  image,
  members,
  tag,
}) => {
  return (
    <Link
      className="block px-1 sm:px-0 bg-grey-200 hover:bg-grey-900 border border-transparent focus:border-grey-900 transition-colors ease-in duration-50"
      to={target}
    >
      <div className="group relative flex gap-3 py-4 px-5 sm:px-6">
        <div className="w-12 h-12 rounded-full overflow-hidden">
          <img
            className="w-full h-full object-cover"
            alt={image.alt}
            src={image.src}
          />
        </div>
        <div className="w-[calc(100%-3rem)] flex flex-col sm:pr-8 md:pr-6 lg:pr-10">
          <div className="w-full">
            <div className="font-plex flex flex-col justify-between">
              <span className="text-lg leading-5 font-medium text-grey-900 line-clamp-1 group-hover:text-white transition-colors ease-in duration-50">
                {name}
              </span>
              <span className="text-xs leading-4 font-normal text-grey-500 line-clamp-1">
                {tag}
              </span>
              <span className="flex items-center text-xs leading-4 font-normal text-grey-500">
                <UserMultiple className="mr-2" /> {members}
              </span>
            </div>
          </div>
          <div className="hidden sm:block w-full mt-3">
            <p className="font-plex text-sm leading-5 font-normal text-black line-clamp-3 group-hover:text-white transition-colors ease-in duration-50">
              {description}
            </p>
          </div>
        </div>
        <ChevronRight
          size={24}
          className="absolute top-1/2 right-4 lg:right-6 -translate-y-2/4 text-grey-500"
        />
      </div>
    </Link>
  );
};
